@@ -107,21 +107,18 @@ class Insight_Definition:
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
-    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple=False):
+    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
-            if (multiple):
-                self.edit_widget_multiple(widget_id, widget_type, query_ids, settings, values, texts, charts)
-            else:
-                self.edit_widget(widget_id, widget_type, query_ids, settings, values, texts, charts)
+            self.edit_widget(widget_id, widget_type, query_ids, settings, values, texts, charts)
         return widget_id
 
-    def add_widget_test(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple= False):
+    def add_widget_multiple(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple= False):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
-            self.edit_widget_multiple_test(widget_id, widget_type,query_ids, settings, values, texts, charts)
+            self.edit_widget_multiple(widget_id, widget_type,query_ids, settings, values, texts, charts)
         return widget_id
 
     def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
@@ -181,67 +178,7 @@ class Insight_Definition:
         self.components = r.json()["components"]
 
 
-    def edit_widget_multiple(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[], multiple=False):
-
-        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
-        columns = []
-        for query in query_ids:
-            if query.startswith("qcomp"):
-
-                qc = self.get_component(query)
-                url_preview = self.smart_insight_url + "/composed_queries/" + qc["settings"]["qc"] + "/preview?limit=100&agentId=" + self.agent_id
-                r = self.__make_post_request(url_preview, {})
-                cols = r.json()["schema"]
-                for col in cols:
-                    if(query not in ((str)(col["id"]))):
-                        col["id"] = query + "-" +col["id"]
-                    columns.append(col)
-                #cols = self.get_columns(query_ids)
-            else:
-                cols = self.get_columns(query_ids)
-                for col in cols:
-                    columns.append(col)
-
-        settings = {}
-        for field in field_codes.keys():
-            ids = []
-            for column in columns:
-                if(column["code"] in field_codes[field] or column["name"] in field_codes[field]):
-                    for query in query_ids:
-                        if(str(field_codes[field]).startswith(query)):
-                           if(str(column["id"]).startswith(query)):
-                               ids.append(column["id"])
-                           else:
-                               continue
-                        else:
-                            ids.append(column["id"])
-            if (len(ids) > 1):
-                settings[field + "_id"] = ids
-            else:
-                settings[field + "_id"] = ids[0]
-
-        for key in values.keys():
-            settings[key + "_id"] = values[key]
-
-        body = {
-            "id" : widget_id,
-            "type": "widget",
-            "name": "Widget",
-            "customName": False,
-            "dependsOn": [],
-            "widgetType": widget_type,
-            "queryIds": query_ids,
-            "settings": settings,
-            "texts": texts,
-            "charts": charts,
-            "valid": True,
-            "queryComponent": False
-        }
-        r = self.__make_put_request(url, body)
-        self.components = r.json()["components"]
-
-
-    def edit_widget_multiple_test(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
+    def edit_widget_multiple(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
         columns = []
